@@ -200,10 +200,6 @@ class NotifyPreview < ActionMailer::Preview
     Notify.changed_milestone_merge_request_email(user.id, merge_request.id, milestone, user.id)
   end
 
-  def member_access_granted_email
-    Notify.member_access_granted_email(member.source_type, member.id).message
-  end
-
   def pages_domain_enabled_email
     cleanup do
       Notify.pages_domain_enabled_email(pages_domain, user).message
@@ -660,7 +656,7 @@ class NotifyPreview < ActionMailer::Preview
     # will obtain an exclusive lease.
     # The `cleanup` method wraps the email-generating-block in a transaction.
     # See issue: https://gitlab.com/gitlab-org/gitlab/-/issues/441523
-    Users::Internal.support_bot
+    Users::Internal.in_organization(project.organization_id).support_bot
   end
 
   def ensure_visual_review_bot_exists
